@@ -139,8 +139,7 @@ void MainWindow::on_searchButton_clicked()
         message->show();
         network->searchKeyWord(this->ui->searchLineEdit->text());
         this->searchWord = this->ui->searchLineEdit->text();
-        this->ui->label->hide();
-        this->ui->label->setHidden(true);
+
         this->ui->label_2->setHidden(true);
         this->ui->searchLineEdit->clear();
     }
@@ -152,7 +151,7 @@ void MainWindow::on_mainWindowButton_clicked()
     {
         ui->mainWindowButton->setDown(true);
         articleList->show();
-        this->ui->label->hide();
+
         this->ui->label_2->hide();
     }
     else
@@ -174,7 +173,7 @@ void MainWindow::on_mainWindowButton_clicked()
     {
         options->hide();
     }
-    this->ui->label->hide();
+
     this->ui->label_2->hide();
 }
 
@@ -189,7 +188,7 @@ void MainWindow::on_playlistsButton_clicked()
     {
         playlist->show();
         ui->playlistsButton->setDown(true);
-        this->ui->label->hide();
+
         this->ui->label_2->hide();
     }
     if (articleList->isVisible())
@@ -204,7 +203,6 @@ void MainWindow::on_playlistsButton_clicked()
     }
     if (options->isVisible())
         options->hide();
-    this->ui->label->hide();
     this->ui->label_2->hide();
 }
 void MainWindow::on_playerButton_clicked()
@@ -218,7 +216,7 @@ void MainWindow::on_playerButton_clicked()
     {
         player->show();
         ui->playerButton->setDown(true);
-        this->ui->label->hide();
+
         this->ui->label_2->hide();
     }
     if (articleList->isVisible())
@@ -233,7 +231,7 @@ void MainWindow::on_playerButton_clicked()
     }
     if (options->isVisible())
         options->hide();
-    this->ui->label->hide();
+
     this->ui->label_2->hide();
 }
 
